searchData={"items":[{"type":"module","doc":"Wraps a Req request in an opentelemetry span.\n\nSpans are not created until the request is completed or errored.","title":"OpentelemetryReq","ref":"OpentelemetryReq.html"},{"type":"module","doc":"It is strongly encouraged to use the [`put_path_params` step](https://hexdocs.pm/req/Req.Steps.html#put_path_params/1) option.\nThis allows the span name to include the `{target}` portion of the span name described in the\n[HTTP Span Name guidelines](https://opentelemetry.io/docs/specs/semconv/http/http-spans/#name).\n\n> #### Requirements {: .info}\n>\n> * `path_params` option should be set along with a templated path. Only `:colon` style is supported\n> * `URLAttributes.url_template()` opt-in attribute must be set to `true`","title":"Req Path Params - OpentelemetryReq","ref":"OpentelemetryReq.html#module-req-path-params"},{"type":"module","doc":"All available required and recommended [Client HTTP Span](https://opentelemetry.io/docs/specs/semconv/http/http-spans/#http-client) semantic conventions are implemented.\nSupported opt-in and experimental attributes can be configured using the `opt_in_attrs` option.","title":"Semantic Conventions - OpentelemetryReq","ref":"OpentelemetryReq.html#module-semantic-conventions"},{"type":"module","doc":"","title":"Options - OpentelemetryReq","ref":"OpentelemetryReq.html#module-options"},{"type":"module","doc":"Otel SemConv requires users to explicitly opt in for any attribute with a\nrequirement level of `opt-in` or `experimental`. To ensure compatability, always use the\nSemConv attribute.\n\nExample:\n```\nclient =\n  Req.new()\n  |> OpentelemetryReq.attach(\n    opt_in_attrs: [SemConv.URLAttributes.url_template()]\n  )\n\nclient\n|> Req.get(\n  url: \"/api/users/:user_id\",\n  path_params: [user_id: user_id]\n)\n```\n\nRequest and response header attributes are opt-in and can be set with the\n`request_header_attrs` and `response_header_attrs` options. Values should be lower-case.","title":"Opt-in Semantic Convention Attributes - OpentelemetryReq","ref":"OpentelemetryReq.html#module-opt-in-semantic-convention-attributes"},{"type":"module","doc":"By default, trace propagation headers are not injected to requests. There are\ntwo options available to propagate trace headers:\n\n  * set `propagate_trace_headers` option to `true` when attaching or in the call\n  * manually use `:otel_propagator_text_map.inject/1`\n\nExample:\n```\nclient =\n  Req.new()\n  |> OpentelemetryReq.attach(propagate_trace_headers: true)\n\n# or\n\nclient =\n  Req.new()\n  |> OpentelemetryReq.attach()\n\nReq.get(client, \"/\", propagate_trace_headers: true)\n```","title":"Trace Header Propagation - OpentelemetryReq","ref":"OpentelemetryReq.html#module-trace-header-propagation"},{"type":"module","doc":"The span name can be overridden by setting the `span_name` option in the call.\n\nExample:\n```\nclient =\n  Req.new()\n  |> OpentelemetryReq.attach()\n\nReq.get(client, \"/\", span_name: \"custom\")\n```\n\n> #### Option Precedence {: .info}\n>\n> Options passed in a request take precedence over those passed in `attach/1`.\n>","title":"Span Name Override - OpentelemetryReq","ref":"OpentelemetryReq.html#module-span-name-override"},{"type":"function","doc":"","title":"OpentelemetryReq.attach/2","ref":"OpentelemetryReq.html#attach/2"},{"type":"type","doc":"Use semantic conventions library to ensure compatability, e.g. `HTTPAttributes.http_request_body_size()`","title":"OpentelemetryReq.opt_in_attr/0","ref":"OpentelemetryReq.html#t:opt_in_attr/0"},{"type":"type","doc":"","title":"OpentelemetryReq.opt_in_attrs/0","ref":"OpentelemetryReq.html#t:opt_in_attrs/0"},{"type":"type","doc":"","title":"OpentelemetryReq.options/0","ref":"OpentelemetryReq.html#t:options/0"},{"type":"extras","doc":"# OpentelemetryReq\n\n[![EEF Observability WG project](https://img.shields.io/badge/EEF-Observability-black)](https://github.com/erlef/eef-observability-wg)\n[![Hex.pm](https://img.shields.io/hexpm/v/opentelemetry_phoenix)](https://hex.pm/packages/opentelemetry_req)\n\n[Req](https://hex.pm/packages/req) plugin for OpenTelemetry instrumentation and propagation.\n\nSee [Docs](https://hex.pm/packages/opentelemetry_req) for usage instructions.","title":"OpentelemetryReq","ref":"readme.html"},{"type":"extras","doc":"```elixir\ndef deps do\n  [\n    {:opentelemetry_req, \"~> 1.0.0-beta.1\"}\n  ]\nend\n```","title":"Installation - OpentelemetryReq","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}